==> datadog-api-client-1.10.0.tar.gz: datadog-api-client-1.10.0/src/datadog_api_client/v1/model/access_role.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (
    ModelSimple,
    cached_property,
)


class AccessRole(ModelSimple):
    allowed_values = {
        "value": {
            "STANDARD": "st",
            "ADMIN": "adm",
            "READ_ONLY": "ro",
            "ERROR": "ERROR",
        },
    }

    validations = {}

    @cached_property
    def openapi_types():
        return {
            "value": (str,),
        }

    def __init__(self, *args, **kwargs):
        """
        The access role of the user. Options are **st** (standard user), **adm** (admin user), or **ro** (read-only user).

        Note that value can be passed either in args or in kwargs, but not in both.

        :param value: If omitted defaults to "st". Must be one of ["st", "adm", "ro", "ERROR"].
        :type value: str
        """
        super().__init__(kwargs)

        if "value" in kwargs:
            value = kwargs.pop("value")
        elif args:
            args = list(args)
            value = args.pop(0)
        else:
            value = "st"

        self._check_pos_args(args)

        self.value = value

        self._check_kw_args(kwargs)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""
        return cls(*args, **kwargs)

==> datadog-api-client-1.11.0.tar.gz: datadog-api-client-1.11.0/src/datadog_api_client/v1/model/access_role.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)


class AccessRole(ModelSimple):

    allowed_values = {
        "value": {
            "STANDARD": "st",
            "ADMIN": "adm",
            "READ_ONLY": "ro",
            "ERROR": "ERROR",
        },
    }

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }

    def __init__(self, *args, **kwargs):
        """
        The access role of the user. Options are **st** (standard user), **adm** (admin user), or **ro** (read-only user).

        Note that value can be passed either in args or in kwargs, but not in both.

        :param value: If omitted defaults to "st". Must be one of ["st", "adm", "ro", "ERROR"].
        :type value: str
        """
        super().__init__(kwargs)

        if "value" in kwargs:
            value = kwargs.pop("value")
        elif args:
            args = list(args)
            value = args.pop(0)
        else:
            value = "st"

        self._check_pos_args(args)

        self.value = value

        self._check_kw_args(kwargs)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""
        return cls(*args, **kwargs)
